@@ -267,7 +267,7 @@ class Settings(object):
 
         self.string(['log'], 
                     'write log entries to FILE (default is to not write log '
-                        'files at all)',
+                        'files at all); use "syslog" to log to system log',
                     metavar='FILE')
         self.choice(['log-level'], 
                     ['debug', 'info', 'warning', 'error', 'critical', 'fatal'],
